@@ -1,4 +1,21 @@
-
+/*
+ *  calendar home widget for the maemo desktop.
+ *  Copyright (C) 2010 Nicolai Hess
+ *  
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *  
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *  
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 #include <libintl.h>
 #include <locale.h>
 #include <ctime>
@@ -53,18 +70,12 @@ cal_home_time_today_midnight(struct tm* today)
 }
 
 static int
-cal_row_count_for_cal_size(const CalSize& cal_size)
+cal_row_count_for_cal_size(const gint& cal_size)
 {
-  switch(cal_size)
-  {
-  case CAL_SIZE_AUTO:
-  case CAL_SIZE_LARGE:
-    return LARGE_ROW_COUNT;
-  case CAL_SIZE_MEDIUM:
-    return MEDIUM_ROW_COUNT;
-  case CAL_SIZE_SMALL:
-    return SMALL_ROW_COUNT;
-  }
+  if(cal_size == -1)
+    return 9;
+  else
+    return cal_size;
 }
 
 static GdkPixbuf* 
@@ -211,6 +222,17 @@ cal_delete_ccomponentset_items(SortedCComponentSet& ccomponent_set)
   }
 }
 
+static gboolean 
+cal_date_on_today(const time_t& t,
+		  CalHomePlugin* desktop_plugin)
+{
+  struct tm* time = localtime(&t);
+
+  return time->tm_year == desktop_plugin->date_today.tm_year &&
+    time->tm_mon == desktop_plugin->date_today.tm_mon &&
+    time->tm_mday== desktop_plugin->date_today.tm_mday;
+}
+
 static void
 cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent_set,
 					   GtkListStore* list_store,
@@ -230,18 +252,16 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
   {
     gtk_list_store_append(list_store,
 			  &iter);
-
     string summary = (*event_iter)->getSummary();
     string component = (*event_iter)->toString();
     time_t start = (*event_iter)->getDateStart();
 
     struct tm* time = localtime(&start);
     char buf[255];
-    if(time->tm_year == desktop_plugin->date_today.tm_year &&
-       time->tm_mon == desktop_plugin->date_today.tm_mon &&
-       time->tm_mday== desktop_plugin->date_today.tm_mday)
+    if(cal_date_on_today((*event_iter)->getDateStart(), desktop_plugin) || 
+       start < mktime(&desktop_plugin->date_today))
     {
-      if((*event_iter)->getAllDay())
+      if((*event_iter)->getAllDay() || start < mktime(&desktop_plugin->date_today))
       {      
 	gtk_list_store_set(list_store, &iter,
 			   0, dgettext("calendar", "cal_va_allday_home"),
@@ -287,40 +307,57 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
 }
 
 static void
-cal_read_ccpompnents_for_type(CCalendar* calendar,
-			      int type,
-			      time_t start_time,
-			      time_t end_time,
-			      SortedCComponentSet& all_components)
+cal_read_ccompnents_for_calendar(CCalendar* calendar,
+				 time_t start_time,
+				 time_t end_time,
+				 SortedCComponentSet& all_components)
 {
   int error = 0;
-  vector<CComponent*> calendars_components = calendar->getComponents(type,
-								     start_time,
-								     end_time,
-								     error);
-  time_t last_start_date = start_time;
-  for(int k = 0;k<calendars_components.size();++k)
+  int offset = 0;
+  int size = 0;
+  int limit = 100;
+  do
   {
-    time_t x = calendars_components[k]->getDateStart();
-    CComponent* component = calendars_components[k];
-    vector<time_t> instance_times =
-      component->getInstanceTimes(last_start_date, 
-				  end_time);
-    if(instance_times.empty())
-      all_components.insert(component);
-    else if(type!=4)
+    vector<CComponent*> calendars_components = calendar->getAllEventsTodos(start_time,
+									   end_time,
+									   limit,
+									   offset,
+									   error);
+  
+    size = calendars_components.size();
+    offset+=limit;
+    time_t last_start_date = start_time;
+    for(int k = 0;k<calendars_components.size();++k)
     {
-      
-      for(vector<time_t>::const_iterator iter = instance_times.begin();
-	  iter!=instance_times.end();
-	  ++iter)
+      time_t x = calendars_components[k]->getDateStart();
+      CComponent* component = calendars_components[k];
+      vector<time_t> instance_times =
+	component->getInstanceTimes(last_start_date, 
+				    end_time);
+    
+      // Remove Task Components now
+      // others are cleaned up later
+      if(calendars_components[k]->getType()==2)
       {
-	CComponent* c = new CComponent(*component);
-	c->setDateStart(*iter);
-	all_components.insert(c);
+	delete calendars_components[k];
       }
+      else
+	if(instance_times.empty())
+	  all_components.insert(component);
+	else
+	{
+	  for(vector<time_t>::const_iterator iter = instance_times.begin();
+	      iter!=instance_times.end();
+	      ++iter)
+	  {
+	    // clone entry with instance time as start time
+	    CComponent* c = new CComponent(*component);
+	    c->setDateStart(*iter);
+	    all_components.insert(c);
+	  }
+	}
     }
-  }
+  }while(size !=0 );
 }
 
 static void
@@ -338,17 +375,10 @@ cal_read_ccomponents_all_visible(SortedCComponentSet& all_components,
     CCalendar* cal = CMulticalendar::MCInstance()->getCalendarById(desktop_plugin->visible_cals[i], error);
     if(error == 500)
     {
-      cal_read_ccpompnents_for_type(cal,
-				    //			    (cal->getCalendarType()==1) ? 4 : 1,
-				    1,
-				    start_time,
-				    end_time,
-				    all_components);
-       cal_read_ccpompnents_for_type(cal, 
-				    4, 
- 				    start_time, 
- 				    end_time, 
- 				    all_components); 
+      cal_read_ccompnents_for_calendar(cal,
+				       start_time,
+				       end_time,
+				       all_components);
     }
     delete cal;
   }
@@ -365,7 +395,7 @@ cal_home_load_db_events(CalHomePlugin* desktop_plugin)
   cal_condense_ccomponents_set_to_list_store(all_components,
 					     desktop_plugin->event_list,
 					     desktop_plugin,
-					     cal_row_count_for_cal_size(desktop_plugin->cal_size));
+					     cal_row_count_for_cal_size(desktop_plugin->cal_row_count));
   cal_delete_ccomponentset_items(all_components);
   cal_fill_event_list_ui(desktop_plugin);
   desktop_plugin->update_view = FALSE;
