@@ -33,7 +33,7 @@ struct CComponentCompare
   }
 };
 
-typedef set<CComponent*, CComponentCompare> SortedCComponentSet;
+typedef multiset<CComponent*, CComponentCompare> SortedCComponentSet;
 
 void
 cal_home_load_db_events(CalHomePlugin* desktop_plugin);
