@@ -58,33 +58,15 @@ static const int CAL_WIDGET_WIDTH = 352;
 void
 cal_widget_resize_for_cal_size(CalHomePlugin* desktop_plugin)
 {
-  CalSize count = (CalSize)gtk_tree_model_iter_n_children(GTK_TREE_MODEL(desktop_plugin->event_list), NULL); 
+  gint row_count = desktop_plugin->cal_row_count;
+  if(row_count == -1)
+    row_count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(desktop_plugin->event_list), NULL); 
   gtk_widget_set_size_request(desktop_plugin->event_list_container, 
 			      CAL_WIDGET_WIDTH, 
-			      CAL_WIDGET_ENTRY_ROW_HEIGHT*count);
-  switch(desktop_plugin->cal_size)
-  {
-  case CAL_SIZE_AUTO:
-    gtk_window_resize(GTK_WINDOW (desktop_plugin), 
-		      CAL_WIDGET_WIDTH, 
-		      (CAL_WIDGET_ENTRY_ROW_HEIGHT*count)+CAL_WIDGET_TITLE_HEIGHT+CAL_WIDGET_BOTTON_HEIGHT);
-    break;
-  case CAL_SIZE_LARGE:
-    gtk_window_resize(GTK_WINDOW (desktop_plugin), 
-		      CAL_WIDGET_WIDTH, 
-		      (CAL_WIDGET_ENTRY_ROW_HEIGHT*LARGE_ROW_COUNT)+CAL_WIDGET_TITLE_HEIGHT+CAL_WIDGET_BOTTON_HEIGHT);
-    break;
-  case CAL_SIZE_MEDIUM:
-    gtk_window_resize(GTK_WINDOW (desktop_plugin), 
-		      CAL_WIDGET_WIDTH, 
-		      (CAL_WIDGET_ENTRY_ROW_HEIGHT*MEDIUM_ROW_COUNT)+CAL_WIDGET_TITLE_HEIGHT+CAL_WIDGET_BOTTON_HEIGHT);
-    break;
-  case CAL_SIZE_SMALL:
-    gtk_window_resize(GTK_WINDOW(desktop_plugin), 
-		      CAL_WIDGET_WIDTH,
-		      (CAL_WIDGET_ENTRY_ROW_HEIGHT*SMALL_ROW_COUNT)+CAL_WIDGET_TITLE_HEIGHT+CAL_WIDGET_BOTTON_HEIGHT);
-    break;
-  }
+			      CAL_WIDGET_ENTRY_ROW_HEIGHT*row_count);
+  gtk_window_resize(GTK_WINDOW (desktop_plugin), 
+		    CAL_WIDGET_WIDTH, 
+		    (CAL_WIDGET_ENTRY_ROW_HEIGHT*row_count)+CAL_WIDGET_TITLE_HEIGHT+CAL_WIDGET_BOTTON_HEIGHT);
 }
 
 static gboolean
@@ -101,20 +83,39 @@ cal_24_time_format()
   return is24Format;
 }
 
+static GdkPixbuf*
+load_calendar_applet_icon()
+{
+  gchar* appleticon;
+  GKeyFile *keyFile;
+  keyFile = g_key_file_new();
+  const gchar* fileName = "/etc/hildon/theme/index.theme";
+  g_key_file_load_from_file (keyFile, fileName, G_KEY_FILE_KEEP_COMMENTS, NULL);
+  appleticon = g_key_file_get_string(keyFile, "X-Hildon-Metatheme", "IconTheme", NULL);
+  g_key_file_free(keyFile);
+  gchar* Aicon = g_strconcat("/usr/share/icons/", appleticon, "/64x64/hildon/calendar_applet.png", NULL);
+
+  GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file(Aicon, NULL);
+  if(pixbuf==NULL)
+    pixbuf = gdk_pixbuf_new_from_file(CAL_BG_IMAGE_PATH, NULL);
+  g_free(appleticon);
+  g_free(Aicon);
+  return pixbuf;
+}
+
 static void
 render_day_on_title(CalHomePlugin* desktop_plugin)
 {
   cairo_t* cr;
-  GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file(CAL_BG_IMAGE_PATH, NULL);
+  GdkPixbuf* pixbuf = load_calendar_applet_icon();
 
   if(!pixbuf)
   {
     return;
   }
-
   int img_width = gdk_pixbuf_get_width(pixbuf);
   int img_height = gdk_pixbuf_get_height(pixbuf);
-  
+
   cairo_surface_t *surface
     = cairo_image_surface_create_for_data(gdk_pixbuf_get_pixels(pixbuf),
                                           CAIRO_FORMAT_RGB24,
@@ -230,8 +231,6 @@ cal_update_if_visible_and_date_changed(CalHomePlugin* desktop_plugin)
     render_day_on_title(desktop_plugin);
     cal_home_load_db_events(desktop_plugin);
     cal_widget_resize_for_cal_size(desktop_plugin);
-
-    //    gtk_widget_queue_draw(GTK_WIDGET(desktop_plugin));    
   }
   else
   {
@@ -251,10 +250,24 @@ handle_db_change(DBusConnection *bus,
 		 gpointer data)
 {
   if(CAL_HOME_IS_HOME_PLUGIN(data))
+  {
+    CalHomePlugin* desktop_plugin = CAL_HOME_PLUGIN(data);
     if(dbus_message_is_signal(msg,CALENDAR_SERVICE, CALENDAR_DBUS_LISTENER_SIGNAL))
     {  
-      CAL_HOME_PLUGIN(data)->update_view = TRUE;
+      gboolean on;
+      g_object_get(desktop_plugin, "is-on-current-desktop", &on, NULL);
+      if(on)
+      {
+	render_day_on_title(desktop_plugin);
+	cal_home_load_db_events(desktop_plugin);
+	cal_widget_resize_for_cal_size(desktop_plugin);
+      }
+      else
+      {
+	CAL_HOME_PLUGIN(desktop_plugin)->update_view = TRUE;
+      }
     }
+  }
   return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
@@ -349,9 +362,9 @@ build_ui(CalHomePlugin *desktop_plugin)
   gtk_container_set_border_width(GTK_CONTAINER(contents), 0);
   desktop_plugin->event_list_container  = gtk_vbox_new(TRUE, 0);
   GtkWidget* title = gtk_hbox_new(FALSE, 0);
-  
-  desktop_plugin->day_image = gtk_image_new_from_icon_name("calendar_applet", 
-							   HILDON_ICON_SIZE_THUMB); 
+  GdkPixbuf* icon = load_calendar_applet_icon();
+  desktop_plugin->day_image = gtk_image_new_from_pixbuf(icon);
+  g_object_unref(icon);
 
   desktop_plugin->day_label = gtk_label_new("");
   desktop_plugin->month_label = gtk_label_new("");
@@ -426,83 +439,35 @@ cal_realize(GtkWidget* widget)
   GTK_WIDGET_CLASS(cal_home_plugin_parent_class)->realize(widget);
 }
 
-static void
-cal_render_background_small(cairo_t* cr, CalHomePlugin* desktop_plugin)
-{
-  cairo_translate(cr, 0, 64); 
-  gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -172); 
-  cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, 5*36); 
-  cairo_fill(cr); 
-  cairo_translate(cr, 0, -64); 
-}
-
-static void
-cal_render_background_medium(cairo_t* cr, CalHomePlugin* desktop_plugin)
-{
-  cairo_translate(cr, 0, 64); 
-  gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -64); 
-  cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, 5*36); 
-  cairo_fill(cr); 
-  cairo_translate(cr, 0, -64); 
-}
-
-static void
-cal_render_background_large(cairo_t* cr, CalHomePlugin* desktop_plugin)
-{
-  cairo_translate(cr, 0, 396-(5*36+8));
-  gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -64);
-  cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, 5*36+8);
-  cairo_fill(cr);
-  cairo_translate(cr, 0, -(396-(5*36+8)));
-  cairo_translate(cr, 0, 64); 
-  gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -64); 
-  cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, 4*36); 
-  cairo_fill(cr); 
-  cairo_translate(cr, 0, -64); 
-}
-
 static void
 cal_render_background_auto(cairo_t* cr, CalHomePlugin* desktop_plugin)
 {
-  CalSize count = (CalSize)gtk_tree_model_iter_n_children(GTK_TREE_MODEL(desktop_plugin->event_list), NULL); 
-  if(count == SMALL_ROW_COUNT)
+  gint row_count = desktop_plugin->cal_row_count;
+  if(row_count == -1)
+    row_count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(desktop_plugin->event_list), NULL); 
+  if(row_count>5)
   {
-    cal_render_background_small(cr, desktop_plugin);
-  }
-  else if(count == MEDIUM_ROW_COUNT)
-  {
-    cal_render_background_medium(cr, desktop_plugin);
-  }
-  else if(count == LARGE_ROW_COUNT)
-  {
-    cal_render_background_large(cr, desktop_plugin);
+    int height = (CAL_WIDGET_ENTRY_ROW_HEIGHT*row_count)+CAL_WIDGET_TITLE_HEIGHT+CAL_WIDGET_BOTTON_HEIGHT;
+    cairo_translate(cr, 0, height-(5*36+8));
+    gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -64);
+    cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, 5*36+8);
+    cairo_fill(cr);
+    cairo_translate(cr, 0, -(height-(5*36+8)));
+
+
+    cairo_translate(cr, 0, 64); 
+    gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -64 -(9-row_count)*36);
+    cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, (row_count-5)*36); 
+    cairo_fill(cr); 
+    cairo_translate(cr, 0, -64); 
   }
   else
   {
-    if(count>5)
-    {
-      int height = (CAL_WIDGET_ENTRY_ROW_HEIGHT*count)+CAL_WIDGET_TITLE_HEIGHT+CAL_WIDGET_BOTTON_HEIGHT;
-      cairo_translate(cr, 0, height-(5*36+8));
-      gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -64);
-      cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, 5*36+8);
-      cairo_fill(cr);
-      cairo_translate(cr, 0, -(height-(5*36+8)));
-
-
-      cairo_translate(cr, 0, 64); 
-      gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -64 -(9-count)*36);
-      cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, (count-5)*36); 
-      cairo_fill(cr); 
-      cairo_translate(cr, 0, -64); 
-    }
-    else
-    {
-      cairo_translate(cr, 0, 64);
-      gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -64 - (5-count)*36);
-      cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, count*36+8);
-      cairo_fill(cr);
-      cairo_translate(cr, 0, -64);
-    }
+    cairo_translate(cr, 0, 64);
+    gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, -64 - (5-row_count)*36);
+    cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, row_count*36+8);
+    cairo_fill(cr);
+    cairo_translate(cr, 0, -64);
   }
 }
 
@@ -515,22 +480,8 @@ cal_expose(GtkWidget* widget, GdkEventExpose *event)
   gdk_cairo_set_source_pixbuf(cr, desktop_plugin->applet_bg, 0, 0);
   cairo_rectangle(cr, 0, 0, CAL_WIDGET_WIDTH, 64);
   cairo_fill(cr);
-  if(desktop_plugin->cal_size == CAL_SIZE_MEDIUM)
-  {
-    cal_render_background_medium(cr, desktop_plugin);
-  }
-  else if(desktop_plugin->cal_size == CAL_SIZE_LARGE)
-  {
-    cal_render_background_large(cr, desktop_plugin);
-  }
-  else if(desktop_plugin->cal_size == CAL_SIZE_SMALL)
-  {
-    cal_render_background_small(cr, desktop_plugin);
-  }
-  else if(desktop_plugin->cal_size == CAL_SIZE_AUTO)
-  {
-    cal_render_background_auto(cr, desktop_plugin);
-  }
+  cal_render_background_auto(cr, desktop_plugin);
+
   cairo_destroy(cr);
   return GTK_WIDGET_CLASS(cal_home_plugin_parent_class)->expose_event(widget, event);
 }
@@ -623,7 +574,7 @@ static void
 cal_load_original_bg(CalHomePlugin* desktop_plugin)
 {
   desktop_plugin->applet_bg = NULL;
-  GdkPixbuf* bg = gdk_pixbuf_new_from_file("/usr/share/themes/default/images/CalendarAppletBackground.png", NULL);
+  GdkPixbuf* bg = gdk_pixbuf_new_from_file("/etc/hildon/theme/images/CalendarAppletBackground.png", NULL);
   if(bg == NULL)
     return;
   GdkPixbuf* stride = gdk_pixbuf_new_subpixbuf(bg, 0, 0, CAL_WIDGET_WIDTH, 252);
@@ -643,7 +594,7 @@ cal_home_plugin_init(CalHomePlugin *desktop_plugin)
   desktop_plugin->dbus_calendar_proxy = NULL;
   desktop_plugin->launch_view = 1;
   desktop_plugin->cal_time_period = CAL_TIME_PERIOD_12MONTH;
-  desktop_plugin->cal_size = CAL_SIZE_MEDIUM;
+  desktop_plugin->cal_row_count = MEDIUM_ROW_COUNT;
   desktop_plugin->has_24_time_format = cal_24_time_format();
   desktop_plugin->update_view = TRUE;
 
