@@ -40,18 +40,7 @@ typedef struct _CalHomePluginClass CalHomePluginClass;
 
 #define CAL_HOME_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CAL_HOME_TYPE_HOME_PLUGIN, CalHomePluginClass))
 
-const int LARGE_ROW_COUNT = 9;
 const int MEDIUM_ROW_COUNT = 5;
-const int SMALL_ROW_COUNT = 2;
-
-
-enum CalSize
-{
-  CAL_SIZE_AUTO = 0,
-  CAL_SIZE_LARGE = 1,
-  CAL_SIZE_MEDIUM = 2,
-  CAL_SIZE_SMALL = 3
-};
 
 enum CalTimePeriod
 {
@@ -84,7 +73,7 @@ struct _CalHomePlugin
   struct tm date_today;
   gboolean update_view;
 
-  CalSize cal_size;
+  gint cal_row_count;
   CalTimePeriod cal_time_period;
   GtkListStore* event_list;
   GtkWidget* day_label;
